@@ -45,7 +45,7 @@ from sphinx.locale import _
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.2.2"
+__version__: str = "0.2.3"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["FixtureDecoratorFinder", "FixtureDocumenter", "is_fixture", "setup"]
@@ -103,10 +103,22 @@ def is_fixture(function: Union[FunctionType, MethodType]) -> Tuple[bool, Optiona
 	:param function:
 	"""
 
+	# TODO: should this be relaxed? It seems inspect.getsource can find these after all.
+	#  But can they work as fixtures?
+	if "<locals>" in function.__qualname__:
+		# Can't get source code for these (issue #6)
+		return False, None
+
 	visitor = FixtureDecoratorFinder()
 
 	try:
-		visitor.visit(ast.parse(inspect.getsource(function)))
+		source = inspect.getsource(function)
+	except OSError:
+		# May be encountered with dataclasses where there's no source for the dynamic methods (issue #6)
+		return False, None
+
+	try:
+		visitor.visit(ast.parse(source))
 	except IndentationError:
 		# Triggered when trying to parse a method
 		return False, None
@@ -125,7 +137,7 @@ class FixtureDocumenter(FunctionDocumenter):
 	objtype = "fixture"
 	directivetype = "fixture"
 	priority = 20
-	object: Union[FunctionType, MethodType]  # noqa: A003
+	object: Union[FunctionType, MethodType]  # noqa: A003  # pylint: disable=redefined-builtin
 
 	def __init__(self, directive: DocumenterBridge, name: str, indent: str = '') -> None:
 		super().__init__(directive, name, indent)
